@@ -1,5 +1,4 @@
-
-#' Find nearest GSOD stations to a specified latitude and longitude
+#' Find Nearest GSOD Stations to a Specified Latitude and Longitude
 #'
 #' Given latitude and longitude values entered as decimal degrees (DD), this
 #' function returns a list (as an atomic vector) of station ID
@@ -35,8 +34,6 @@
 #' @export nearest_stations
 
 nearest_stations <- function(LAT, LON, distance) {
-  # CRAN NOTE avoidance
-  isd_history <- distance_km <- NULL #nocov
   # load current local copy of isd_history
   load(system.file("extdata", "isd_history.rda", package = "GSODR"))
 
@@ -58,8 +55,8 @@ nearest_stations <- function(LAT, LON, distance) {
 
     # radius of earth
     6371 * 2 * asin(sqrt(`+`(
-      (sin(delta_lat / 2)) ^ 2,
-      cos(lat1) * cos(lat2) * (sin(delta_lon / 2)) ^ 2
+      (sin(delta_lat / 2))^2,
+      cos(lat1) * cos(lat2) * (sin(delta_lon / 2))^2
     )))
   }
 
@@ -72,5 +69,4 @@ nearest_stations <- function(LAT, LON, distance) {
   )]
 
   return(subset(isd_history[order(distance_km)], distance_km < distance)[[1]])
-
 }
