@@ -1,7 +1,7 @@
 
 # Check that nearest stations functions properly -------------------------------
 test_that("nearest stations returns station IDs nearest to farthest", {
-  skip_on_cran()
+  skip_if_offline()
   n <-
     nearest_stations(LAT = -27.5598,
                      LON = 151.9507,
